==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ToolActionRadioDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionRadioDescription } from "./ToolActionRadioDescription";
/**
 * @hidden
 */
export let ToolActionRadioDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionRadioDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionRadioDescriptionMetadata.a == null) {
                ToolActionRadioDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionRadioDescriptionMetadata.c(ToolActionRadioDescriptionMetadata.a);
            }
            if (a.j(ToolActionRadioDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolActionRadioDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("RadioGroup", "String");
        }
        static d(a) {
            ToolActionRadioDescriptionMetadata.b(a);
            a.aa("ToolActionRadio", () => new ToolActionRadioDescription());
            a.z("ToolActionRadio", ToolActionRadioDescriptionMetadata.a);
        }
    }
    ToolActionRadioDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionRadioDescriptionMetadata, 'ToolActionRadioDescriptionMetadata');
    ToolActionRadioDescriptionMetadata.a = null;
    return ToolActionRadioDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolActionRadioDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionRadioDescription } from "./ToolActionRadioDescription";
/**
 * @hidden
 */
export let ToolActionRadioDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionRadioDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionRadioDescriptionMetadata.a == null) {
                ToolActionRadioDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionRadioDescriptionMetadata.c(ToolActionRadioDescriptionMetadata.a);
            }
            if (a.k(ToolActionRadioDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolActionRadioDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("RadioGroup", "String");
        }
        static d(a) {
            ToolActionRadioDescriptionMetadata.b(a);
            a.ac("ToolActionRadio", () => new ToolActionRadioDescription());
            a.ab("ToolActionRadio", ToolActionRadioDescriptionMetadata.a);
        }
    }
    ToolActionRadioDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionRadioDescriptionMetadata, 'ToolActionRadioDescriptionMetadata');
    ToolActionRadioDescriptionMetadata.a = null;
    return ToolActionRadioDescriptionMetadata;
})();
